History Module
==============

Note that this is the developer API reference for the internal history module. See
:ref:`history array<datastruct-history-array>` for the user reference.

.. automodule:: history

.. autoclass:: History
  :member-order: bysource
  :members:

  .. automethod:: __init__
